@@ -195,6 +195,27 @@ class HistoricalWebsocket:
             print(f"{Style.BRIGHT}{Fore.RED}Failed to connect with error message = {welcome_msg['message']}{Style.RESET_ALL}")
             self.hist_socket.close()
 
+    def get_n_historic_bars(self, contract, end_time, no_of_bars, bar_size):
+        if bar_size.lower() is not 'eod' and bar_size.lower() is not 'tick':
+            bar_size = bar_size.replace(' ', '')
+            if bar_size[-1] == 's':
+                bar_size = bar_size[:-1]
+        self.hist_socket.send(f'{{"method": "gethistorylastnbars", "interval": "{bar_size}", "symbol": "{contract}", "nbars": "{no_of_bars}", "to": "{end_time}"}}')
+        raw_hist_data = self.hist_socket.recv()
+        json_response = json.loads(raw_hist_data)
+        if json_response['success']:
+            hist_data = json_response['data']
+            if bar_size.lower() == 'tick':
+                hist_data = self.hist_tick_data_to_dict_list(hist_data, contract)
+            elif bar_size.lower() == 'eod':
+                hist_data = self.hist_eod_data_to_dict_list(hist_data, contract)
+            else:
+                hist_data = self.hist_bar_data_to_dict_list(hist_data)
+            return hist_data
+        else:
+            print(f'{Style.BRIGHT}{Fore.RED}ERROR: Your request failed with error "{json_response["message"]}"{Style.RESET_ALL}')
+            return []
+
     def get_historic_data(self, contract, end_time, start_time, bar_size):
         if bar_size.lower() == 'tick':
             return self.get_hist_tick_data(contract, end_time, start_time)
@@ -218,18 +239,6 @@ class HistoricalWebsocket:
             print(f'{Style.BRIGHT}{Fore.RED}ERROR: Your request failed with error "{json_response["message"]}"{Style.RESET_ALL}')
             return []
 
-    def get_n_historic_bars(self, contract, end_time, no_of_bars, bar_size):
-        self.hist_socket.send(f'{{"method": "gethistorylastnbars", "interval": "{bar_size}", "symbol": "{contract}", "nbars": "{no_of_bars}", "to": "{end_time}"}}')
-        raw_hist_data = self.hist_socket.recv()
-        json_response = json.loads(raw_hist_data)
-        if json_response['success']:
-            hist_data = json_response['data']
-            hist_data = self.hist_bar_data_to_dict_list(hist_data)
-            return hist_data
-        else:
-            print(f'{Style.BRIGHT}{Fore.RED}ERROR: Your request failed with error "{json_response["message"]}"{Style.RESET_ALL}')
-            return []
-
     @staticmethod
     def hist_bar_data_to_dict_list(hist_data):
         data_list = []
@@ -303,7 +312,7 @@ class HistoricalWebsocket:
     def hist_eod_data_to_dict_list(hist_data, contract):  # No need for symbol other than printing
         data_list = []
         for j in hist_data:
-            data_list.append({'time': datetime.strptime(j[0], '%d-%m-%Y'),
+            data_list.append({'time': datetime.strptime(j[0], '%Y-%m-%d'),
                               'o': float(j[1]),
                               'h': float(j[2]),
                               'l': float(j[3]),
